poscarUtils — PyProcar 6.2.1 documentation

Skip to main content
`Ctrl`+`K`

# poscarUtils

- The `pyprocar.pyposcar.poscar_modify` class is used for general manipulation of the crystal geometry of an electronic structure calculation.

- The `pyprocar.pyposcar.poscar_supercell` class is used to create a supercell with the given dimension.

- The `pyprocar.pyposcar.poscarDiff()` function is used to compare two POSCAR files or objects.

`pyprocar.pyposcar.poscar_modify`(poscar[, ...]) | High-level class to change properties of a Poscar-object.
`pyprocar.pyposcar.poscar_supercell`(poscar[, ...]) | class to generate a supercell by providing a supercell matrix.
`pyprocar.pyposcar.poscarDiff`(poscar1, poscar2) | It compares two different Poscar objects.